@@ -1,6 +1,6 @@
 package Statocles;
 # ABSTRACT: A static site generator
-$Statocles::VERSION = '0.040';
+$Statocles::VERSION = '0.041';
 # The currently-running site.
 # I hate this, but I know of no better way to ensure that we always have access
 # to a Mojo::Log object, while still being relatively useful, without having to
@@ -28,11 +28,12 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =head1 SYNOPSIS
 
-    # !!! Read the Statocles::Help guide to set up a site.yml config file
+    # Create a new site
+    statocles create www.example.com
 
     # Create a new blog post
     export EDITOR=vim
