@@ -1,6 +1,6 @@
 package Statocles::Document;
 # ABSTRACT: Base class for all Statocles documents
-$Statocles::Document::VERSION = '0.040';
+$Statocles::Document::VERSION = '0.041';
 use Statocles::Base 'Class';
 
 
@@ -50,10 +50,10 @@ has links => (
 );
 
 
-has last_modified => (
+has date => (
     is => 'rw',
     isa => InstanceOf['Time::Piece'],
-    predicate => 'has_last_modified',
+    predicate => 'has_date',
 );
 
 1;
@@ -68,7 +68,7 @@ Statocles::Document - Base class for all Statocles documents
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =head1 DESCRIPTION
 
@@ -118,9 +118,10 @@ supported attributes. The most common attributes are:
     text - The text of the link
     href - The URL for the link
 
-=head2 last_modified
+=head2 date
 
-The date/time this document was last modified.
+The date/time this document is for. For pages, this is the last modified date.
+For blog posts, this is the post's date.
 
 =head1 AUTHOR
 
