@@ -1,6 +1,6 @@
 package Statocles::Page;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::VERSION = '0.040';
+$Statocles::Page::VERSION = '0.041';
 use Statocles::Base 'Role';
 use Statocles::Template;
 use Text::Markdown;
@@ -28,7 +28,7 @@ has path => (
 );
 
 
-has last_modified => (
+has date => (
     is => 'ro',
     isa => InstanceOf['Time::Piece'],
     lazy => 1,
@@ -123,7 +123,7 @@ Statocles::Page - Render documents into HTML
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =head1 DESCRIPTION
 
@@ -145,9 +145,9 @@ The application this page came from, so we can give it to the templates.
 
 The absolute URL path to save this page to.
 
-=head2 last_modified
+=head2 date
 
-The last modified date/time of this page. A L<Time::Piece> object.
+The date of this page. Used for last updated date and blog post dates.
 
 =head2 links
 
