@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::Document::VERSION = '0.040';
+$Statocles::Page::Document::VERSION = '0.041';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Text::Markdown;
@@ -30,11 +30,11 @@ has author => (
 );
 
 
-has '+last_modified' => (
+has '+date' => (
     lazy => 1,
     default => sub {
         my ( $self ) = @_;
-        $self->document->last_modified || Time::Piece->new;
+        $self->document->date || Time::Piece->new;
     },
 );
 
@@ -93,7 +93,7 @@ Statocles::Page::Document - Render documents into HTML
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =head1 DESCRIPTION
 
@@ -113,9 +113,9 @@ The title of the page.
 
 The author of the page.
 
-=head2 last_modified
+=head2 date
 
-Get the last modified date of this page by checking the document.
+Get the date of this page by checking the document.
 
 =head2 tags
 
