@@ -1,6 +1,6 @@
 package Statocles::Page::List;
 # ABSTRACT: A page presenting a list of other pages
-$Statocles::Page::List::VERSION = '0.040';
+$Statocles::Page::List::VERSION = '0.041';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use List::Util qw( max );
@@ -21,11 +21,11 @@ has [qw( next prev )] => (
 );
 
 
-has '+last_modified' => (
+has '+date' => (
     lazy => 1,
     default => sub {
         my ( $self ) = @_;
-        $self->pages->[0]->last_modified;
+        $self->pages->[0]->date;
     },
 );
 
@@ -64,7 +64,7 @@ sub paginate {
             pages => [ @{$pages}[ @{ $sets[$i] } ] ],
             ( $next ? ( next => $next ) : () ),
             ( $i > 0 ? ( prev => $prev ) : () ),
-            last_modified => $pages->[0]->last_modified,
+            date => $pages->[0]->date,
             %args,
         );
     }
@@ -92,7 +92,7 @@ Statocles::Page::List - A page presenting a list of other pages
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =head1 DESCRIPTION
 
@@ -113,10 +113,10 @@ The path to the next page in the pagination series.
 
 The path to the previous page in the pagination series.
 
-=head2 last_modified
+=head2 date
 
-Get the last modified date of this list. By default, this is the last modified date
-of the first page in the list of pages.
+Get the date of this list. By default, this is the latest date of the first
+page in the list of pages.
 
 =head2 search_change_frequency
 
