@@ -1,6 +1,6 @@
 package Statocles::Store::File;
 # ABSTRACT: A store made up of plain files
-$Statocles::Store::File::VERSION = '0.040';
+$Statocles::Store::File::VERSION = '0.041';
 use Statocles::Base 'Class';
 with 'Statocles::Store';
 use Scalar::Util qw( weaken blessed );
@@ -139,21 +139,21 @@ sub _parse_frontmatter {
 
 sub _thaw_document {
     my ( $self, $doc ) = @_;
-    if ( exists $doc->{last_modified} ) {
+    if ( exists $doc->{date} ) {
 
         my $dt;
         eval {
-            $dt = Time::Piece->strptime( $doc->{last_modified}, $DATETIME_FORMAT );
+            $dt = Time::Piece->strptime( $doc->{date}, $DATETIME_FORMAT );
         };
 
         if ( $@ ) {
             eval {
-                $dt = Time::Piece->strptime( $doc->{last_modified}, $DATE_FORMAT );
+                $dt = Time::Piece->strptime( $doc->{date}, $DATE_FORMAT );
             };
 
             if ( $@ ) {
-                die sprintf "Could not parse last_modified '%s'. Does not match '%s' or '%s'",
-                    $doc->{last_modified},
+                die sprintf "Could not parse date '%s'. Does not match '%s' or '%s'",
+                    $doc->{date},
                     $DATETIME_FORMAT,
                     $DATE_FORMAT,
                     ;
@@ -161,7 +161,7 @@ sub _thaw_document {
 
         }
 
-        $doc->{last_modified} = $dt;
+        $doc->{date} = $dt;
     }
     return $doc;
 }
@@ -188,8 +188,8 @@ sub write_document {
 
 sub _freeze_document {
     my ( $self, $doc ) = @_;
-    if ( exists $doc->{last_modified} ) {
-        $doc->{last_modified} = $doc->{last_modified}->strftime( $DATETIME_FORMAT );
+    if ( exists $doc->{date} ) {
+        $doc->{date} = $doc->{date}->strftime( $DATETIME_FORMAT );
     }
     return $doc;
 }
@@ -257,7 +257,7 @@ Statocles::Store::File - A store made up of plain files
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =head1 DESCRIPTION
 
