@@ -1,6 +1,6 @@
 package Statocles::Test;
 # ABSTRACT: Common test routines for Statocles
-$Statocles::Test::VERSION = '0.040';
+$Statocles::Test::VERSION = '0.041';
 use Statocles::Base;
 use Test::More;
 use Test::Exception;
@@ -149,7 +149,7 @@ sub test_pages {
         ok $page->DOES( 'Statocles::Page' ), 'must be a Statocles::Page';
 
         if ( !$page->isa( 'Statocles::Page::Feed' ) ) {
-            isa_ok $page->last_modified, 'Time::Piece', 'must set a last_modified';
+            isa_ok $page->date, 'Time::Piece', 'must set a date';
         }
 
         if ( !$page_tests{ $page->path } ) {
@@ -302,7 +302,7 @@ Statocles::Test - Common test routines for Statocles
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =head1 DESCRIPTION
 
